// Den ganzen Zeichensatz als PBM nach stdout ausgeben.

#include <stdio.h>
#include <stdlib.h>

#include "vektor-zeichen.h"

#if VF_INT_BITS == 8
#define PIX_X 256
#define PIX_Y 256
#else
#define PIX_X 800
#define PIX_Y 800
#endif

unsigned char pixel[PIX_X][PIX_Y];

int max_x = 0;
int max_y = 0;
int min_x = PIX_X;
int min_y = PIX_Y;

char * text =
        "0123456789.:\n"
        "ABCDEFGHIJK\n"
        "LMNOPQRSTUV\n"
        "WXYZ\n"
        "abcdefghijklmn\n"
        "opqrstuvwxyz\n"
        "+-*?,;<>^_="
        ;

letter_drawinfo_t drawinfo;

void beam_skip (void) {}

void beam_xy (vf_uint_t x, vf_uint_t y)
{
    if (x >= PIX_X || y >= PIX_Y)
        return;

    pixel[x][y] = 1;

    if (x < min_x) min_x = x;
    if (y < min_y) min_y = y;

    if (x > max_x) max_x = x;
    if (y > max_y) max_y = y;
}

void text2pbm (letter_drawinfo_t * di, const char * text, int zoom)
{
    di->zoom = zoom;
    di->text = text;
    di->start.x = 5;
    di->start.y = PIX_Y-5-7*zoom;
    di->beam_xy = beam_xy;
    di->beam_skip = beam_skip;

    while (!draw_letters (di));

    min_x -= 5; max_x += 5;
    min_y -= 5; max_y += 5;
    if (min_x < 0)        min_x = 0;
    if (max_x > PIX_X-1)  max_x = PIX_X-1;
    if (min_y < 0)        min_y = 0;
    if (max_y > PIX_Y-1)  max_y = PIX_Y-1;

    printf ("P1\n%d %d\n", max_x-min_x+1, max_y-min_y+1);

    for (int y = max_y; y >= min_y; y--)
    {
        for (int x = min_x; x <= max_x; x++)
            putc ('0' + pixel[x][y], stdout);

        printf ("\n");
    }
}

/*
void text2stat (letter_drawinfo_t * di, int zoom)
{
    const uint8_t * addr = vektor_zeichen_data;

    if (zoom < 2)
        zoom = 2;

    char c;
    int xy2 = 0, p1=0, p0=0;
    int xy = 0;

    do
    {
        int offset = addr - vektor_zeichen_data;
        int size;

        c = *addr++;
        size = 2 + (0x1f & *addr++);
        addr += size-2;

        for (int z = 1; z <= zoom; z++)
        {
            xy = count_pixels (c ? c : VF_UNKNOWN, z);

            if (z == 1)
            {
                if (c == VF_UNKNOWN)
                    fprintf (stderr, " { .c='\\%03o', ", VF_UNKNOWN);
                else
                    fprintf (stderr, " { .c='%c', ", c);

                fprintf (stderr, ".off=% 4d, .size = % 3d, ", offset, size);
            }

            if (z == 2)
            {
                p1 = xy-xy2;
                p0 = xy2-p1;
                fprintf (stderr, ".pix = { % 3d, % 3d", p0, p1);
            }

            if (z > 2 && p1 != xy-xy2)
                fprintf (stderr, " /""* !!![%d] % 3d *""/ ", z, xy-xy2);

            xy2 = xy;
        }

        fprintf (stderr, " }\n");

    } while ((uint8_t) c != VF_UNKNOWN);
}
*/

int main (int argc, char * argv[])
{
    int zoom;

    if (argc >= 2)
        sscanf (argv[1], "%d", & zoom);

    if (argc >= 3)
        sscanf (argv[2], "%d", & drawinfo.proportional);

    if (zoom > 0)
    {
        text2pbm (& drawinfo, text, zoom);
        return 0;
    }
/*
    if (zoom < 0)
    {
        text2stat (& drawinfo, -zoom);
        return 1;
    }
*/
    return 1;
}

