#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>

#include "vektor-zeichen.h"

int one_path = 0;
int pixels = 0;

signed int max_x = -32768;
signed int min_x =  32767;
signed int max_y = -32768;
signed int min_y = 32767;

char svg[60000];

char * text =
        "0123456789.:\n"
        "ABCDEFGHIJK\n"
        "LMNOPQRSTUV\n"
        "WXYZ\n"
        "abcdefghijklmn\n"
        "opqrstuvwxyz\n"
        "+-*?,;<>^_="
        ;

char * text2 =
        "Franz jagt im\n"
        "komplett verwahr-\n"
        "losten Taxi quer\n"
        "durch Bayern."
        ;


letter_drawinfo_t drawinfo;

int skip;

int px, py, npix;
int startx, starty;
int firstchar = 1;
int firstpath = 1;
int ignore;
int zoom;

char buf[200];

#define append(x...)                                            \
do                                                              \
{                                                               \
    sprintf (buf, ##x);                                         \
    if (strlen (svg) + strlen (buf) +1 >= sizeof (svg))         \
    {                                                           \
        fprintf (stderr, "\n Interner Puffer ist zu kein!\n");  \
        exit (-1);                                              \
    }                                                           \
    strcat (svg, buf);                                          \
}                                                               \
while (0)

void finish_char()
{
    if (!skip && npix == 1 && !pixels)
            append ("h0 ");
    append ("\"/>\n");
    append ("\t</g>\n");
}

void notify_char (letter_drawinfo_t * di, char c)
{
    ignore = (c == '\n');

    if (ignore)
        return;
    
    if (!firstchar)
        finish_char();

    append ("\t<g id=\"");
    
    if (c == '<' || c == '>')// || (!isalnum (c) && !ispunct(c)))
        append ("ascii-%d", (unsigned char) c);
    else
        append ("%c", c);

    startx = di->p.x;
    starty = 500-di->p.y;
    
    append ("\" transform=\"translate(%d,%d)\"", startx, starty);
    append (">\n");

    firstchar = 0;
    firstpath = 1;
    npix = 0;
}
                  
void beam_skip (void)
{
    char str[20];
    
    if (ignore)
        return;
    
    if (!skip)
    {
        if (npix == 1 && !pixels)
            append (" h0");

        if (one_path)
        {
            if (firstpath)
                append ("\t\t<path d=\"");
        }
        else
        {
            if (!firstpath)
                append ("\"/>\n");
            append ("\t\t<path d=\"");
        }
    
        npix = 0;
        firstpath = 0;
    }

    skip = 1;
}

void beam_xy (vf_uint_t xx, vf_uint_t yy)
{
    if (ignore)
        return;

    short x = xx;
    short y = yy;

    y = 500-y + 6*zoom;

    if (x < min_x) min_x = x;
    if (y < min_y) min_y = y;

    if (x > max_x) max_x = x;
    if (y > max_y) max_y = y;


    int ppx = x-startx;
    int ppy = y-starty;

    if (pixels)
    {
        append ("M%d,%dh.001 ", ppx, ppy);
    }
    else
    {
        if (skip)
            append ("M%d,%d ", ppx, ppy);
        else
        {
            if (px == ppx && py == ppy)
                return;
            
            if (px == ppx)
                append ("v%d ", ppy-py);
            else
                if (py == ppy)
                    append ("h%d ", ppx-px);
                else
                    append ("l%d,%d ", ppx-px, ppy-py);
        }
    }

    npix++;

    px = ppx;
    py = ppy;
    
    skip = 0;
}

void text2svg (letter_drawinfo_t * di, const char * text, int zoom)
{
    di->zoom = zoom;
    di->text = text;
    di->start.x = 100;
    di->start.y = 500;
    di->beam_xy = beam_xy;
    di->beam_skip = beam_skip;

    while (1)
    {
        if (draw_letters (di))
            break;
    }

}
    
int main (int argc, char * argv[])
{
    if (argc >= 2)
        sscanf (argv[1], "%d", & zoom);

    if (argc >= 3)
        sscanf (argv[2], "%d", & drawinfo.proportional);

    if (argc >= 4)
        sscanf (argv[3], "%d", & pixels);

    if (argc >= 5)
        sscanf (argv[4], "%d", & one_path);

    if (zoom > 0)
    {
        int b = 20;
        text2svg (& drawinfo, text, zoom);
        finish_char();

        int x0, x1, y0, y1, w, h;
        b = zoom;

        x0 = min_x-b;
        y0 = min_y-b;
        x1 = max_x+b;
        y1 = max_y+b;

        w = x1-x0+1;
        h = y1-y0+1;
        
        printf ("<?xml version=\"1.0\" encoding=\"iso-latin-1\" standalone=\"no\" ?>\n"
                "<svg "
                "\txmlns=\"http://www.w3.org/2000/svg\"\n"
                "\tviewBox=\"%d %d %d %d\"\n"
                "\twidth=\"%d\"\n"
                "\theight=\"%d\"\n"
                "\tversion=\"1.1\"\n"
                "\t>\n\n",
                x0, y0, w, h,
                (int) 400.*w/h, 400);

        printf ("<rect x='%d' y='%d' width='%d' height='%d' fill='white' stroke='none'/>\n", x0, y0, w, h);

        char * stroke = (pixels)
            ? "stroke='#000' stroke-linecap='square' stroke-width='1'"
            : "stroke='#309' stroke-opacity='0.6' stroke-linecap='round' stroke-width='1.1'";
        printf ("<g "
                "stroke-linejoin='round' "
                "fill='none' "
                "%s >\n", stroke);

        printf (svg);
        printf ("</g></svg>\n");
        return 0;
    }
    
    return 1;
}

